/***********************************************************************
 *
 * FileName:
 *		PnpDtp.h
 *
 * Description:
 *    Declaration of DayTime functions for "Palm Network Programming"
 *    DayTime Peer (Client and Server) sample application.
 *
 * Note:
 *    Because this is example code, most of the error checking and safety
 *    measures (such as setting unlocked pointers to NULL) have been removed.
 *    This would need to be added back for production-ready code.
 *
 * Copyright  2001, Greg Winton.
 * All rights reserved.
 *
 *******************************************************************/

#ifndef __PNPDTP_H__
#define __PNPDTP_H__

// Standard application definitions
#include "PnpDefs.h"
#include <NetMgr.h>

// --------------------------------------------------------------------
// Public constant declarations
// --------------------------------------------------------------------
#define pnpMaxDayTimeString 30
#define pnpMaxCommandString 10

// --------------------------------------------------------------------
// Public structure declarations
// --------------------------------------------------------------------
typedef struct {
   Boolean isNetConnect;      // Are we connected to network.
   
   // DayTime Client information.
   NetSocketRef cliSocket;    // Client socket reference.
   UInt32 cliLastSend;        // Client last send time.
   
   // DayTime Server information.
   NetSocketRef svrSocket;    // Server socket reference.
   NetSocketAddrType svrPeer; // Server peer address (last client request).
   UInt16 svrPeerLen;         // Length of server peer address.
   Boolean svrIsBusy;         // Is the server busy?
   
   // File Descriptor Sets for checking socket's Read, Write states.
   NetFDSetType readFDs;      // Read file descriptor set.
   NetFDSetType writeFDs;     // Write file descriptor set.
} PnpDtpInfoType, * PnpDtpInfoPtr;

// --------------------------------------------------------------------
// Public function declarations
// --------------------------------------------------------------------

/*
   PnpDtpInit:
   Initialize DayTime peer. 
   Params:  infoP    Pointer to DayTime Session information.
   Returns: 0        Success.
            <0       Error code.
*/
Err PnpDtpInit (PnpDtpInfoPtr infoP);

/*
   PnpDtpTerm:
   Terminate DayTime peer. 
   Params:  infoP    Pointer to DayTime Session information.
   Returns: 0        Success.
            <0       Error code.
*/
Err PnpDtpTerm (PnpDtpInfoPtr infoP);

/*
   PnpDtpProcess:
   Process any incoming or outgoing DayTime events.
   Params:  infoP    DayTime Session information.
   Returns: 0        One or more DayTime transactions completed.
            <0       No progress made.
*/
Err PnpDtpProcess (PnpDtpInfoPtr infoP);

/*
   PnpDtpRun:
   Start the DayTime peer.
   Params:  infoP    DayTime Session object.
            host     Client Peer host name.
   Returns: 0        Success.
            < 0      Error.
*/
Err PnpDtpRun (PnpDtpInfoPtr infoP, Char* host);

/*
   PnpDtpStop:
   Stop the DayTime peer.
   Params:  infoP    DayTime Session object.
   Returns: 0        Success.
            < 0      Error.
*/
Err PnpDtpStop (PnpDtpInfoPtr infoP);

/*
   PnpDtpIsRunning:
   Check if the we can run the daytime peer.
   Params:  infoP    DayTime Peer Session information.
   Returns: true     DayTime peer is running.
            false    DayTime peer is not running.
*/
Boolean PnpDtpIsRunning (PnpDtpInfoPtr infoP);

#endif	// __PNPDTP_H__
